/**
 * @file
 * JavaScript behaviors for the Static Files admin interface.
 */

(function ($, Drupal, once) {

  'use strict';

  /**
   * Add toggle behavior to the static files table.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.staticFilesAdmin = {
    attach: function (context, settings) {
      // Use 'once' to ensure we only initialize the buttons once
      once('staticFilesAdminToggle', '.resource-toggle', context).forEach(function (button) {
        $(button).on('click', function (event) {
          event.preventDefault();
          
          const $button = $(this);
          const fileId = $button.attr('data-file-id');
          const $resourceRows = $('.resource-parent-' + fileId);
          
          // Toggle visibility of child rows
          if ($button.hasClass('closed')) {
            $button.removeClass('closed').addClass('open');
            $button.attr('aria-expanded', 'true');
            $resourceRows.slideDown(200);
          } else {
            $button.removeClass('open').addClass('closed');
            $button.attr('aria-expanded', 'false');
            $resourceRows.slideUp(200);
          }
        });
      });
      
      // Add expand/collapse all functionality
      once('staticFilesAdminToggleAll', '.static-files-toggle-all', context).forEach(function (button) {
        $(button).on('click', function (event) {
          event.preventDefault();
          
          const $button = $(this);
          const action = $button.attr('data-action');
          
          if (action === 'expand') {
            $('.resource-toggle.closed').trigger('click');
            $button.attr('data-action', 'collapse').text(Drupal.t('Collapse all'));
          } else {
            $('.resource-toggle.open').trigger('click');
            $button.attr('data-action', 'expand').text(Drupal.t('Expand all'));
          }
        });
      });
      // Add checkbox functionality
      once('staticFilesAdminCheckbox', '.file-select-checkbox', context).forEach(function (checkbox) {
        // Update selected_items hidden field with checked items
        $(checkbox).on('change', function () {
          const selectedItems = [];
          $('.file-select-checkbox:checked').each(function () {
            selectedItems.push($(this).val());
          });
          console.log(selectedItems);
          $('#selected-items').val(selectedItems.join(','));
        });
      });
    }
  };
  Drupal.behaviors.staticFilesBulkOperations = {
    attach: function (context, settings) {
      const $table = $('.static-files-table', context);
      const $bulkOps = $('#static-node-bulk-operations-form', context);
      const $status = $('.bulk-operations__item--status', $bulkOps);
        $status.html(Drupal.t('No items selected'));
      // Function to update bulk operations visibility
      function updateBulkOperations() {
        const selectedCount = $('.static-files-table input[type="checkbox"]:checked', context).length;
        if (selectedCount > 0) {
          $bulkOps.addClass('is-sticky');
          $status.html(Drupal.formatPlural(selectedCount, '1 item selected', '@count items selected'));
        } else {
          $status.html(Drupal.t('No items selected'));
          $bulkOps.removeClass('is-sticky');
        }
      }

      // Initialize
      updateBulkOperations();

      // Update on checkbox changes
      once('bulk-ops', '.static-files-table', context).forEach(table => {
        $(table).on('change', 'input[type="checkbox"]', updateBulkOperations);
      });
    }
  };
})(jQuery, Drupal, once);